@@ -3,6 +3,7 @@ from aishield.constants import (
     FileFormat,
     ReportType,
 )
+from aishield.utils.util import check_or_create_directory
 
 
 class JobDetails:
@@ -10,7 +11,7 @@ class JobDetails:
     Instantiates to details of a vulnerability analysis job
     """
     def __init__(self, job_id=None, job_monitor_uri=None, model_id=None, data_upload_uri=None, label_upload_uri=None,
-                 model_upload_uri=None):
+                 minmax_upload_uri: str = None, model_upload_uri=None, clean_model_upload_uris=[]):
         """
         Constructor for Job Details class.
         Parameters
@@ -20,7 +21,9 @@ class JobDetails:
         model_id: model id obtained after model registration
         data_upload_uri: uri returned by model registration service where data file in zip needs to be uploaded
         label_upload_uri: uri returned by model registration service where label file in zip needs to be uploaded
+        minmax_upload_uri: uri returned by model registration service where minmax(for tabular data) file in zip needs to be uploaded
         model_upload_uri: uri returned by model registration service where model file in zip needs to be uploaded
+        clean_model_upload_uris: uri's returned by model registration service where clean model files in zip needs to be uploaded (for model poison check)
         """
         self.job_id = job_id
         self.job_monitor_uri = job_monitor_uri
@@ -28,6 +31,9 @@ class JobDetails:
         self.data_upload_uri = data_upload_uri
         self.label_upload_uri = label_upload_uri
         self.model_upload_uri = model_upload_uri
+        self.minmax_upload_uri = minmax_upload_uri  # for Tabular datatype
+        self.clean_model_upload_uris = clean_model_upload_uris  # for model poison analysis
+
 
     @property
     def job_id(self):
@@ -61,6 +67,14 @@ class JobDetails:
     def label_upload_uri(self, label_upload_uri):
         self.__label_upload_uri = label_upload_uri
 
+    @property
+    def minmax_upload_uri(self):
+        return self.__minmax_upload_uri
+
+    @minmax_upload_uri.setter
+    def minmax_upload_uri(self, minmax_upload_uri):
+        self.__minmax_upload_uri = minmax_upload_uri
+
     @property
     def model_upload_uri(self):
         return self.__model_upload_uri
@@ -69,6 +83,14 @@ class JobDetails:
     def model_upload_uri(self, model_upload_uri):
         self.__model_upload_uri = model_upload_uri
 
+    @property
+    def clean_model_upload_uris(self):
+        return self.__clean_model_upload_uris
+
+    @clean_model_upload_uris.setter
+    def clean_model_upload_uris(self, clean_model_upload_uris):
+        self.__clean_model_upload_uris = clean_model_upload_uris
+
     @property
     def model_id(self):
         return self.__model_id
@@ -119,4 +141,5 @@ class OutputConf:
 
     @save_folder_path.setter
     def save_folder_path(self, save_folder_path):
+        check_or_create_directory(save_folder_path)
         self.__save_folder_path = save_folder_path
