@@ -7,11 +7,14 @@ LOG = logger.getLogger(__name__)
 
 class VulnConfig(ICVulnerabilityConfig):
     def __init__(self, defense_generate):
-        super().__init__(defense_generate)
+        super().__init__()
         if defense_generate:
-            LOG.warning('No defense exist for model poisoning now')
+            self.vulnerability_threshold = 0
+        else:
+            self.vulnerability_threshold = 1
         self.attack = Attack.POISONING
 
+
     def get_all_params(self):
         params = super(VulnConfig, self).get_all_params()
         params = delete_keys_from_dict(params, ['task_type', 'attack'])
