@@ -5,10 +5,23 @@ from aishield.utils.util import delete_keys_from_dict
 
 class VulnConfig(TCVulnerabilityConfig):
     def __init__(self, defense_generate):
-        super().__init__(defense_generate)
+        super().__init__()
+        if defense_generate:
+            self.vulnerability_threshold = 0
+        else:
+            self.vulnerability_threshold = 1
+        self.number_of_attack_queries = 200
         self.attack_type = 'blackbox'
         self.attack = Attack.EXTRACTION
 
+    @property
+    def number_of_attack_queries(self):
+        return self.__number_of_attack_queries
+
+    @number_of_attack_queries.setter
+    def number_of_attack_queries(self, num_attack_queries):
+        self.__number_of_attack_queries = num_attack_queries
+
     @property
     def attack_type(self):
         return self.__attack_type
